#!/usr/bin/env python

import sys
import os
import glob
from argparse import ArgumentParser, FileType
from pathlib import Path

from GeoServer.GeoServer import GeoServer
from Rasterizer.Rasterizer import Rasterizer

arg_parser = ArgumentParser(description='Create raster data from input data files')
arg_parser.add_argument('-i', metavar='input_path', help='Input directory containing input files')
arg_parser.add_argument('-p', metavar='file_pattern', default="*.*", help='Pattern to select input files from input '
                                                                          'directory')
arg_parser.add_argument('-o', metavar='output_dir', help='Output directory')
arg_parser.add_argument('-c', metavar='config file', default="./rasterizer.conf",
                        help='Configuration file')
arg_parser.add_argument('-w', metavar='workspace', help='Workspace to create in GeoServer')
arg_parser.add_argument('-d', action='store_true', dest='debug', help='Enable debug logging')
args = arg_parser.parse_args()

if __name__ == '__main__':
    rasterCreator = Rasterizer(os.path.abspath(args.c), args.debug, 'rasterizer.log')
    geoServer = GeoServer(os.path.abspath(args.c), args.debug, 'rasterizer.log')

    layers = set()
    for file in glob.glob(args.i + "/" + args.p):
        imagePaths = rasterCreator.rasterizeECMWFMeteoCSV(file, args.o)
        if imagePaths == 1:
            sys.exit(1)

        for layerName, imageInfo in imagePaths.items():
            geoServer.registerTile(args.w, layerName, imageInfo)
            layers.add(layerName)
    sys.exit(0)