from pyspark import SparkContext
from weeklyAggregation import aggregate_meteo_files
import sys

import datetime
import re

from os import listdir, walk
from os.path import isfile, join

"""
The code in the __main__ block will be executed on a single node, the 'driver'. It describes the different steps that need
to be executed in parallel.
"""


def group_files_weekly(files):
    grouped_files = []

    week = []
    for file in files:
        week.append(file)

        match_obj = re.search(r'(\d{4})(\d{2})(\d{2}).*.tif', file, re.M|re.I)
        day_of_week = datetime.date(int(match_obj.group(1)), int(match_obj.group(2)), int(match_obj.group(3))).isocalendar()[2]

        if day_of_week == 7:
            grouped_files.append(week)
            week = []

    return grouped_files


if __name__ == '__main__':

    if len(sys.argv) > 2:
        input_dir = sys.argv[1]
        output_dir = sys.argv[2]
        lta_mapping_uri = sys.argv[3]

        start_date = datetime.datetime.strptime(sys.argv[4] if len(sys.argv) > 4 and sys.argv[4] else '1970-01-01', '%Y-%m-%d')
        end_date = datetime.datetime.strptime(sys.argv[5] if len(sys.argv) > 5 and sys.argv[5] else '2100-01-01', '%Y-%m-%d')

        sc = SparkContext(appName='python-spark-meteo-ecmwf')

        directories = [x[0] for x in walk(input_dir) if x[0] != input_dir and x[0][-4:] != '1989']

        geotiff_files = []
        for d in directories:
            geotiff_files.extend([f for f in listdir(d) if isfile(join(d, f)) and f.endswith('.tif') and start_date <= datetime.datetime.strptime(f[0:8], '%Y%m%d') <= end_date])
        geotiff_files.sort()

        geotiff_files_grouped = group_files_weekly(geotiff_files)

        try:
            # filesRDD = sc.parallelize(geotiff_files_grouped, round(len(geotiff_files_grouped)/10))
            filesRDD = sc.parallelize(geotiff_files_grouped)
            filesRDD.foreach(lambda files: aggregate_meteo_files(files, input_dir, output_dir, lta_mapping_uri))
        except Exception as e:
            print e
        finally:
            if sc is not None:
                sc.stop()
